# -*- coding: utf-8 -*-
# rclog/__init__.py


from . import setlog as set_log
from .getlog import get_log as get_log
